@@ -26,8 +26,9 @@ class DnsPlugin(Plugin):
             if app['web_service']:
                 apps[app['fullname']] = app['web_ip']
 
-            if app['public_url']:
-                apps[app['public_url']] = app['web_ip']
+            if app['public_urls'] and 'web_ip' in app:
+                for url in app['public_urls']:
+                    apps[url] = app['web_ip']
 
         logger.info('Installing new app list: %s' % str(apps))
 
